EVMStream

Struct EVMStream 

pub struct EVMStream { /* private fields */ }
EVM WebSocket streaming client for HyperEVM

Stream EVM events via WebSocket on the /nanoreth namespace.

Example

use hyperliquid_sdk::EVMStream;

#[tokio::main]
async fn main() -> Result<(), Box<dyn std::error::Error>> {
    let mut stream = EVMStream::new(Some("https://your-endpoint.quiknode.pro/TOKEN".to_string()));

    // Subscribe to new block headers
    stream.new_heads(|header| {
        println!("New block: {:?}", header);
    });

    // Subscribe to contract logs
    stream.logs(
        Some(serde_json::json!({"address": "0x..."})),
        |log| println!("Log: {:?}", log),
    );

    stream.start()?;
    Ok(())
}

Implementations

Source

impl EVMStream

pub fn new(endpoint: Option<String>) -> Self

Create a new EVM stream client

pub fn configure(self, config: EVMStreamConfig) -> Self

Configure stream options

pub fn on_error<F>(self, f: F) -> Self
where F: Fn(String) + Send + Sync + 'static,

Set error callback

pub fn on_close<F>(self, f: F) -> Self
where F: Fn() + Send + Sync + 'static,

Set close callback

pub fn on_open<F>(self, f: F) -> Self
where F: Fn() + Send + Sync + 'static,

Set open callback

pub fn on_state_change<F>(self, f: F) -> Self
where F: Fn(EVMConnectionState) + Send + Sync + 'static,

Set state change callback

pub fn state(&self) -> EVMConnectionState

Get current connection state

pub fn connected(&self) -> bool

Check if connected

pub fn new_heads<F>(&mut self, callback: F) -> &mut Self
where F: Fn(Value) + Send + Sync + 'static,

Subscribe to new block headers

Fires a notification each time a new header is appended to the chain, including during chain reorganizations.

pub fn logs<F>(&mut self, filter: Option<Value>, callback: F) -> &mut Self
where F: Fn(Value) + Send + Sync + 'static,

Subscribe to contract event logs

Returns logs that are included in new imported blocks and match the given filter criteria.

Arguments
  • filter - Filter parameters with optional address and topics
  • callback - Function called with each matching log
pub fn new_pending_transactions<F>(&mut self, callback: F) -> &mut Self
where F: Fn(Value) + Send + Sync + 'static,

Subscribe to pending transaction hashes

Returns the hash for all transactions that are added to the pending state.

pub fn subscriptions(&self) -> Vec<String>

Get list of active subscription IDs

pub fn start(&mut self) -> Result<()>

Start the stream in background (non-blocking)

pub async fn run(&mut self) -> Result<()>

Run the stream (blocking)

pub fn stop(&mut self)

Stop the stream