Modules
- block_
streaming_ client - Generated client implementations.
- l4_
book_ update - Nested message and enum types in
L4BookUpdate. - order_
book_ streaming_ client - Generated client implementations.
- streaming_
client - Generated client implementations.
- subscribe_
request - Nested message and enum types in
SubscribeRequest. - subscribe_
update - Nested message and enum types in
SubscribeUpdate.
Structs
- Block
- Filter
Values - Container for filter values
- L2Book
Request - Request parameters for L2 book streaming.
- L2Book
Update - An L2 book update: full snapshot of aggregated price levels at a point in time.
- L2Level
- A single aggregated price level.
- L4Book
Diff - Incremental L4 book diff: raw order statuses and book diffs for one block.
- L4Book
Request - Request parameters for L4 book streaming.
- L4Book
Snapshot - Full L4 order book snapshot for a single coin.
- L4Book
Update - An L4 book update: either a full snapshot or an incremental diff.
- L4Order
- A single L4 order with full details.
- Ping
- Ping
Request - Ping
Response - Pong
- Stream
Response - Stream
Subscribe - Subscribe
Request - — Requests —
- Subscribe
Update - — Responses —
- Timestamp
Enums
- Stream
Type - — Data Types —