#[repr(i32)]pub enum StreamType {
Unknown = 0,
Trades = 1,
Orders = 2,
BookUpdates = 3,
Twap = 4,
Events = 5,
Blocks = 6,
WriterActions = 7,
}Expand description
— Data Types —
Variants
Implementations
Sourceimpl StreamType
impl StreamType
Sourceimpl StreamType
impl StreamType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.