pub struct Info { /* private fields */ }Expand description
Info API client
Implementations
Sourceimpl Info
impl Info
Sourcepub async fn meta_and_asset_ctxs(&self) -> Result<Value>
pub async fn meta_and_asset_ctxs(&self) -> Result<Value>
Get metadata with asset contexts (real-time funding, open interest)
Sourcepub async fn spot_meta_and_asset_ctxs(&self) -> Result<Value>
pub async fn spot_meta_and_asset_ctxs(&self) -> Result<Value>
Get spot metadata with contexts
Sourcepub async fn exchange_status(&self) -> Result<Value>
pub async fn exchange_status(&self) -> Result<Value>
Get exchange status
Sourcepub async fn perp_dexes(&self) -> Result<Value>
pub async fn perp_dexes(&self) -> Result<Value>
Get all perp DEXes (HIP-3)
Sourcepub async fn perp_categories(&self) -> Result<Value>
pub async fn perp_categories(&self) -> Result<Value>
Get perp categories
Sourcepub async fn perp_annotation(&self, asset: &str) -> Result<Value>
pub async fn perp_annotation(&self, asset: &str) -> Result<Value>
Get perp annotation for an asset
Sourcepub async fn l2_book(
&self,
coin: &str,
n_sig_figs: Option<u32>,
mantissa: Option<u32>,
) -> Result<Value>
pub async fn l2_book( &self, coin: &str, n_sig_figs: Option<u32>, mantissa: Option<u32>, ) -> Result<Value>
Get L2 order book
Sourcepub async fn recent_trades(&self, coin: &str) -> Result<Value>
pub async fn recent_trades(&self, coin: &str) -> Result<Value>
Get recent trades
Sourcepub async fn candles(
&self,
coin: &str,
interval: &str,
start_time: u64,
end_time: Option<u64>,
) -> Result<Value>
pub async fn candles( &self, coin: &str, interval: &str, start_time: u64, end_time: Option<u64>, ) -> Result<Value>
Get candlestick data
Sourcepub async fn funding_history(
&self,
coin: &str,
start_time: u64,
end_time: Option<u64>,
) -> Result<Value>
pub async fn funding_history( &self, coin: &str, start_time: u64, end_time: Option<u64>, ) -> Result<Value>
Get funding history
Sourcepub async fn predicted_fundings(&self) -> Result<Value>
pub async fn predicted_fundings(&self) -> Result<Value>
Get predicted fundings
Sourcepub async fn clearinghouse_state(
&self,
user: &str,
dex: Option<&str>,
) -> Result<Value>
pub async fn clearinghouse_state( &self, user: &str, dex: Option<&str>, ) -> Result<Value>
Get clearinghouse state (positions, margin)
Sourcepub async fn spot_clearinghouse_state(&self, user: &str) -> Result<Value>
pub async fn spot_clearinghouse_state(&self, user: &str) -> Result<Value>
Get spot clearinghouse state (token balances)
Sourcepub async fn open_orders(&self, user: &str, dex: Option<&str>) -> Result<Value>
pub async fn open_orders(&self, user: &str, dex: Option<&str>) -> Result<Value>
Get open orders
Sourcepub async fn frontend_open_orders(
&self,
user: &str,
dex: Option<&str>,
) -> Result<Value>
pub async fn frontend_open_orders( &self, user: &str, dex: Option<&str>, ) -> Result<Value>
Get frontend open orders (enhanced)
Sourcepub async fn order_status(
&self,
user: &str,
oid: u64,
dex: Option<&str>,
) -> Result<Value>
pub async fn order_status( &self, user: &str, oid: u64, dex: Option<&str>, ) -> Result<Value>
Get order status
Sourcepub async fn historical_orders(&self, user: &str) -> Result<Value>
pub async fn historical_orders(&self, user: &str) -> Result<Value>
Get historical orders
Sourcepub async fn user_fills(
&self,
user: &str,
aggregate_by_time: bool,
) -> Result<Value>
pub async fn user_fills( &self, user: &str, aggregate_by_time: bool, ) -> Result<Value>
Get user fills
Sourcepub async fn user_fills_by_time(
&self,
user: &str,
start_time: u64,
end_time: Option<u64>,
) -> Result<Value>
pub async fn user_fills_by_time( &self, user: &str, start_time: u64, end_time: Option<u64>, ) -> Result<Value>
Get user fills by time range
Sourcepub async fn user_funding(
&self,
user: &str,
start_time: Option<u64>,
end_time: Option<u64>,
) -> Result<Value>
pub async fn user_funding( &self, user: &str, start_time: Option<u64>, end_time: Option<u64>, ) -> Result<Value>
Get user funding payments
Sourcepub async fn user_rate_limit(&self, user: &str) -> Result<Value>
pub async fn user_rate_limit(&self, user: &str) -> Result<Value>
Get user rate limit
Sourcepub async fn sub_accounts(&self, user: &str) -> Result<Value>
pub async fn sub_accounts(&self, user: &str) -> Result<Value>
Get sub-accounts
Sourcepub async fn extra_agents(&self, user: &str) -> Result<Value>
pub async fn extra_agents(&self, user: &str) -> Result<Value>
Get extra agents (API keys)
Sourcepub async fn batch_clearinghouse_states(&self, users: &[&str]) -> Result<Value>
pub async fn batch_clearinghouse_states(&self, users: &[&str]) -> Result<Value>
Batch query clearinghouse states for multiple users
Sourcepub async fn vault_summaries(&self) -> Result<Value>
pub async fn vault_summaries(&self) -> Result<Value>
Get all vault summaries
Sourcepub async fn vault_details(
&self,
vault_address: &str,
user: Option<&str>,
) -> Result<Value>
pub async fn vault_details( &self, vault_address: &str, user: Option<&str>, ) -> Result<Value>
Get vault details
Sourcepub async fn user_vault_equities(&self, user: &str) -> Result<Value>
pub async fn user_vault_equities(&self, user: &str) -> Result<Value>
Get user vault equities
Sourcepub async fn leading_vaults(&self, user: &str) -> Result<Value>
pub async fn leading_vaults(&self, user: &str) -> Result<Value>
Get leading vaults
Sourcepub async fn delegations(&self, user: &str) -> Result<Value>
pub async fn delegations(&self, user: &str) -> Result<Value>
Get delegations
Sourcepub async fn delegator_summary(&self, user: &str) -> Result<Value>
pub async fn delegator_summary(&self, user: &str) -> Result<Value>
Get delegator summary
Sourcepub async fn delegator_history(&self, user: &str) -> Result<Value>
pub async fn delegator_history(&self, user: &str) -> Result<Value>
Get delegator history
Sourcepub async fn delegator_rewards(&self, user: &str) -> Result<Value>
pub async fn delegator_rewards(&self, user: &str) -> Result<Value>
Get delegator rewards
Sourcepub async fn user_twap_slice_fills(
&self,
user: &str,
limit: Option<u32>,
) -> Result<Value>
pub async fn user_twap_slice_fills( &self, user: &str, limit: Option<u32>, ) -> Result<Value>
Get user TWAP slice fills
Sourcepub async fn user_twap_history(&self, user: &str) -> Result<Value>
pub async fn user_twap_history(&self, user: &str) -> Result<Value>
Get user TWAP history
Sourcepub async fn borrow_lend_user_state(&self, user: &str) -> Result<Value>
pub async fn borrow_lend_user_state(&self, user: &str) -> Result<Value>
Get borrow/lend user state
Sourcepub async fn borrow_lend_reserve_state(&self, token: &str) -> Result<Value>
pub async fn borrow_lend_reserve_state(&self, token: &str) -> Result<Value>
Get borrow/lend reserve state
Sourcepub async fn all_borrow_lend_reserve_states(&self) -> Result<Value>
pub async fn all_borrow_lend_reserve_states(&self) -> Result<Value>
Get all borrow/lend reserve states
Sourcepub async fn user_abstraction(&self, user: &str) -> Result<Value>
pub async fn user_abstraction(&self, user: &str) -> Result<Value>
Get user abstraction mode
Sourcepub async fn user_dex_abstraction(&self, user: &str) -> Result<Value>
pub async fn user_dex_abstraction(&self, user: &str) -> Result<Value>
Get user DEX abstraction mode
Sourcepub async fn liquidatable(&self) -> Result<Value>
pub async fn liquidatable(&self) -> Result<Value>
Get liquidatable positions
Sourcepub async fn max_market_order_ntls(&self) -> Result<Value>
pub async fn max_market_order_ntls(&self) -> Result<Value>
Get max market order notionals
Sourcepub async fn max_builder_fee(&self, user: &str, builder: &str) -> Result<Value>
pub async fn max_builder_fee(&self, user: &str, builder: &str) -> Result<Value>
Get max builder fee
Sourcepub async fn active_asset_data(&self, user: &str, asset: &str) -> Result<Value>
pub async fn active_asset_data(&self, user: &str, asset: &str) -> Result<Value>
Get active asset data
Sourcepub async fn token_details(&self, token_id: &str) -> Result<Value>
pub async fn token_details(&self, token_id: &str) -> Result<Value>
Get token details
Sourcepub async fn spot_deploy_state(&self, user: &str) -> Result<Value>
pub async fn spot_deploy_state(&self, user: &str) -> Result<Value>
Get spot deployment state for user
Sourcepub async fn spot_pair_deploy_auction_status(&self) -> Result<Value>
pub async fn spot_pair_deploy_auction_status(&self) -> Result<Value>
Get spot pair deploy auction status
Sourcepub async fn user_non_funding_ledger_updates(
&self,
user: &str,
start_time: Option<u64>,
end_time: Option<u64>,
) -> Result<Value>
pub async fn user_non_funding_ledger_updates( &self, user: &str, start_time: Option<u64>, end_time: Option<u64>, ) -> Result<Value>
Get user’s non-funding ledger updates (deposits, withdrawals, transfers)
Sourcepub async fn user_to_multi_sig_signers(&self, user: &str) -> Result<Value>
pub async fn user_to_multi_sig_signers(&self, user: &str) -> Result<Value>
Get multi-sig signers for a user
Sourcepub async fn gossip_root_ips(&self) -> Result<Value>
pub async fn gossip_root_ips(&self) -> Result<Value>
Get gossip root IPs for the network
Sourcepub async fn perp_deploy_auction_status(&self) -> Result<Value>
pub async fn perp_deploy_auction_status(&self) -> Result<Value>
Get perpetual deploy auction status
Sourcepub async fn perps_at_open_interest_cap(&self) -> Result<Value>
pub async fn perps_at_open_interest_cap(&self) -> Result<Value>
Get perps that are at their open interest cap
Sourcepub async fn validator_l1_votes(&self) -> Result<Value>
pub async fn validator_l1_votes(&self) -> Result<Value>
Get L1 validator votes
Sourcepub async fn approved_builders(&self, user: &str) -> Result<Value>
pub async fn approved_builders(&self, user: &str) -> Result<Value>
Get list of approved builders for a user
Sourcepub async fn all_perp_metas(&self) -> Result<Value>
pub async fn all_perp_metas(&self) -> Result<Value>
Get consolidated universe, margin tables, asset contexts across all DEXs
Sourcepub async fn perp_dex_limits(&self, dex: &str) -> Result<Value>
pub async fn perp_dex_limits(&self, dex: &str) -> Result<Value>
Get OI caps and transfer limits for builder-deployed markets
Sourcepub async fn perp_dex_status(&self, dex: &str) -> Result<Value>
pub async fn perp_dex_status(&self, dex: &str) -> Result<Value>
Get total net deposits for builder-deployed markets
Sourcepub async fn aligned_quote_token_info(&self, token: u32) -> Result<Value>
pub async fn aligned_quote_token_info(&self, token: u32) -> Result<Value>
Get aligned quote token information