pub fn agent_signing_hash(chain: Chain, connection_id: B256) -> B256
Compute the EIP-712 signing hash for an Agent struct wrapping a connection ID.
This is the final hash that users sign for MessagePack-based actions.