Info

Struct Info 

pub struct Info { /* private fields */ }
Info API client

Implementations

Source

impl Info

pub async fn meta(&self) -> Result<Value>

Get exchange metadata (perp assets, decimals, etc.)

pub async fn spot_meta(&self) -> Result<Value>

Get spot metadata

pub async fn meta_and_asset_ctxs(&self) -> Result<Value>

Get metadata with asset contexts (real-time funding, open interest)

pub async fn spot_meta_and_asset_ctxs(&self) -> Result<Value>

Get spot metadata with contexts

pub async fn exchange_status(&self) -> Result<Value>

Get exchange status

pub async fn perp_dexes(&self) -> Result<Value>

Get all perp DEXes (HIP-3)

pub async fn perp_categories(&self) -> Result<Value>

Get perp categories

pub async fn perp_annotation(&self, asset: &str) -> Result<Value>

Get perp annotation for an asset

pub async fn all_mids(&self, dex: Option<&str>) -> Result<Value>

Get all mid prices

pub async fn get_mid(&self, asset: &str) -> Result<f64>

Get mid price for a single asset

pub async fn l2_book( &self, coin: &str, n_sig_figs: Option<u32>, mantissa: Option<u32>, ) -> Result<Value>

Get L2 order book

pub async fn recent_trades(&self, coin: &str) -> Result<Value>

Get recent trades

pub async fn candles( &self, coin: &str, interval: &str, start_time: u64, end_time: Option<u64>, ) -> Result<Value>

Get candlestick data

pub async fn funding_history( &self, coin: &str, start_time: u64, end_time: Option<u64>, ) -> Result<Value>

Get funding history

pub async fn predicted_fundings(&self) -> Result<Value>

Get predicted fundings

pub async fn clearinghouse_state( &self, user: &str, dex: Option<&str>, ) -> Result<Value>

Get clearinghouse state (positions, margin)

pub async fn spot_clearinghouse_state(&self, user: &str) -> Result<Value>

Get spot clearinghouse state (token balances)

pub async fn open_orders(&self, user: &str, dex: Option<&str>) -> Result<Value>

Get open orders

pub async fn frontend_open_orders( &self, user: &str, dex: Option<&str>, ) -> Result<Value>

Get frontend open orders (enhanced)

pub async fn order_status( &self, user: &str, oid: u64, dex: Option<&str>, ) -> Result<Value>

Get order status

pub async fn historical_orders(&self, user: &str) -> Result<Value>

Get historical orders

pub async fn user_fills( &self, user: &str, aggregate_by_time: bool, ) -> Result<Value>

Get user fills

pub async fn user_fills_by_time( &self, user: &str, start_time: u64, end_time: Option<u64>, ) -> Result<Value>

Get user fills by time range

pub async fn user_funding( &self, user: &str, start_time: Option<u64>, end_time: Option<u64>, ) -> Result<Value>

Get user funding payments

pub async fn user_fees(&self, user: &str) -> Result<Value>

Get user fees

pub async fn user_rate_limit(&self, user: &str) -> Result<Value>

Get user rate limit

pub async fn user_role(&self, user: &str) -> Result<Value>

Get user role

pub async fn sub_accounts(&self, user: &str) -> Result<Value>

Get sub-accounts

pub async fn extra_agents(&self, user: &str) -> Result<Value>

Get extra agents (API keys)

pub async fn portfolio(&self, user: &str) -> Result<Value>

Get portfolio history

pub async fn web_data2(&self, user: &str) -> Result<Value>

Get comprehensive web data

pub async fn batch_clearinghouse_states(&self, users: &[&str]) -> Result<Value>

Batch query clearinghouse states for multiple users

pub async fn vault_summaries(&self) -> Result<Value>

Get all vault summaries

pub async fn vault_details( &self, vault_address: &str, user: Option<&str>, ) -> Result<Value>

Get vault details

pub async fn user_vault_equities(&self, user: &str) -> Result<Value>

Get user vault equities

pub async fn leading_vaults(&self, user: &str) -> Result<Value>

Get leading vaults

pub async fn delegations(&self, user: &str) -> Result<Value>

Get delegations

pub async fn delegator_summary(&self, user: &str) -> Result<Value>

Get delegator summary

pub async fn delegator_history(&self, user: &str) -> Result<Value>

Get delegator history

pub async fn delegator_rewards(&self, user: &str) -> Result<Value>

Get delegator rewards

pub async fn user_twap_slice_fills( &self, user: &str, limit: Option<u32>, ) -> Result<Value>

Get user TWAP slice fills

pub async fn user_twap_history(&self, user: &str) -> Result<Value>

Get user TWAP history

pub async fn borrow_lend_user_state(&self, user: &str) -> Result<Value>

Get borrow/lend user state

pub async fn borrow_lend_reserve_state(&self, token: &str) -> Result<Value>

Get borrow/lend reserve state

pub async fn all_borrow_lend_reserve_states(&self) -> Result<Value>

Get all borrow/lend reserve states

pub async fn user_abstraction(&self, user: &str) -> Result<Value>

Get user abstraction mode

pub async fn user_dex_abstraction(&self, user: &str) -> Result<Value>

Get user DEX abstraction mode

pub async fn liquidatable(&self) -> Result<Value>

Get liquidatable positions

pub async fn max_market_order_ntls(&self) -> Result<Value>

Get max market order notionals

pub async fn max_builder_fee(&self, user: &str, builder: &str) -> Result<Value>

Get max builder fee

pub async fn active_asset_data(&self, user: &str, asset: &str) -> Result<Value>

Get active asset data

pub async fn token_details(&self, token_id: &str) -> Result<Value>

Get token details

pub async fn spot_deploy_state(&self, user: &str) -> Result<Value>

Get spot deployment state for user

pub async fn spot_pair_deploy_auction_status(&self) -> Result<Value>

Get spot pair deploy auction status

pub async fn referral(&self, user: &str) -> Result<Value>

Get user’s referral information

pub async fn user_non_funding_ledger_updates( &self, user: &str, start_time: Option<u64>, end_time: Option<u64>, ) -> Result<Value>

Get user’s non-funding ledger updates (deposits, withdrawals, transfers)

pub async fn user_to_multi_sig_signers(&self, user: &str) -> Result<Value>

Get multi-sig signers for a user

pub async fn gossip_root_ips(&self) -> Result<Value>

Get gossip root IPs for the network

pub async fn perp_deploy_auction_status(&self) -> Result<Value>

Get perpetual deploy auction status

pub async fn perps_at_open_interest_cap(&self) -> Result<Value>

Get perps that are at their open interest cap

pub async fn validator_l1_votes(&self) -> Result<Value>

Get L1 validator votes

pub async fn approved_builders(&self, user: &str) -> Result<Value>

Get list of approved builders for a user

pub async fn all_perp_metas(&self) -> Result<Value>

Get consolidated universe, margin tables, asset contexts across all DEXs

pub async fn perp_dex_limits(&self, dex: &str) -> Result<Value>

Get OI caps and transfer limits for builder-deployed markets

pub async fn perp_dex_status(&self, dex: &str) -> Result<Value>

Get total net deposits for builder-deployed markets

pub async fn aligned_quote_token_info(&self, token: u32) -> Result<Value>

Get aligned quote token information